@@ -53,36 +53,36 @@ V4LRadioConfiguration::V4LRadioConfiguration (TQWidget *parent, SoundStreamID ss
     m_PlaybackChannelHelper(comboPlaybackMixerChannel),
     m_CaptureChannelHelper (comboCaptureMixerChannel)
 {
-    TQObject::connect(buttonSelectRadioDevice, TQT_SIGNAL(clicked()),
-                     this, TQT_SLOT(selectRadioDevice()));
+    TQObject::connect(buttonSelectRadioDevice, TQ_SIGNAL(clicked()),
+                     this, TQ_SLOT(selectRadioDevice()));
     editRadioDevice->installEventFilter(this);
-    TQObject::connect(editMinFrequency, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(guiMinFrequencyChanged(int)));
-    TQObject::connect(editMaxFrequency, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(guiMaxFrequencyChanged(int)));
+    TQObject::connect(editMinFrequency, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(guiMinFrequencyChanged(int)));
+    TQObject::connect(editMaxFrequency, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(guiMaxFrequencyChanged(int)));
 
-    TQObject::connect(editDeviceVolume, TQT_SIGNAL(valueChanged(double)),
-                     this, TQT_SLOT(slotDeviceVolumeChanged(double)));
-    TQObject::connect(editTreble, TQT_SIGNAL(valueChanged(double)),
-                     this, TQT_SLOT(slotTrebleChanged(double)));
-    TQObject::connect(editBass, TQT_SIGNAL(valueChanged(double)),
-                     this, TQT_SLOT(slotBassChanged(double)));
-    TQObject::connect(editBalance, TQT_SIGNAL(valueChanged(double)),
-                     this, TQT_SLOT(slotBalanceChanged(double)));
+    TQObject::connect(editDeviceVolume, TQ_SIGNAL(valueChanged(double)),
+                     this, TQ_SLOT(slotDeviceVolumeChanged(double)));
+    TQObject::connect(editTreble, TQ_SIGNAL(valueChanged(double)),
+                     this, TQ_SLOT(slotTrebleChanged(double)));
+    TQObject::connect(editBass, TQ_SIGNAL(valueChanged(double)),
+                     this, TQ_SLOT(slotBassChanged(double)));
+    TQObject::connect(editBalance, TQ_SIGNAL(valueChanged(double)),
+                     this, TQ_SLOT(slotBalanceChanged(double)));
 
-    TQObject::connect(sliderDeviceVolume, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(slotDeviceVolumeChanged(int)));
-    TQObject::connect(sliderTreble, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(slotTrebleChanged(int)));
-    TQObject::connect(sliderBass, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(slotBassChanged(int)));
-    TQObject::connect(sliderBalance, TQT_SIGNAL(valueChanged(int)),
-                     this, TQT_SLOT(slotBalanceChanged(int)));
+    TQObject::connect(sliderDeviceVolume, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(slotDeviceVolumeChanged(int)));
+    TQObject::connect(sliderTreble, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(slotTrebleChanged(int)));
+    TQObject::connect(sliderBass, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(slotBassChanged(int)));
+    TQObject::connect(sliderBalance, TQ_SIGNAL(valueChanged(int)),
+                     this, TQ_SLOT(slotBalanceChanged(int)));
 
-    TQObject::connect(comboPlaybackMixerDevice, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotComboPlaybackMixerSelected(int)));
-    TQObject::connect(comboCaptureMixerDevice, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotComboCaptureMixerSelected(int)));
+    TQObject::connect(comboPlaybackMixerDevice, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotComboPlaybackMixerSelected(int)));
+    TQObject::connect(comboCaptureMixerDevice, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotComboCaptureMixerSelected(int)));
 
     sliderBalance->installEventFilter(this);
 }
